@@ -30,7 +30,8 @@ func NewWorkingTreeContext(c *ContextCommon) *WorkingTreeContext {
 
 	getDisplayStrings := func(_ int, _ int) [][]string {
 		showFileIcons := icons.IsIconEnabled() && c.UserConfig().Gui.ShowFileIcons
-		lines := presentation.RenderFileTree(viewModel, c.Model().Submodules, showFileIcons)
+		showNumstat := c.UserConfig().Gui.ShowNumstatInFilesView
+		lines := presentation.RenderFileTree(viewModel, c.Model().Submodules, showFileIcons, showNumstat)
 		return lo.Map(lines, func(line string, _ int) []string {
 			return []string{line}
 		})
