@@ -61,8 +61,8 @@ func (self *MergeConflictsHelper) EscapeMerge() error {
 		// to continue the merge/rebase. In that case, we don't want to then push the
 		// files context over it.
 		// So long as both places call OnUIThread, we're fine.
-		if self.c.IsCurrentContext(self.c.Contexts().MergeConflicts) {
-			return self.c.PushContext(self.c.Contexts().Files)
+		if self.c.Context().IsCurrent(self.c.Contexts().MergeConflicts) {
+			self.c.Context().Push(self.c.Contexts().Files)
 		}
 		return nil
 	})
@@ -93,14 +93,15 @@ func (self *MergeConflictsHelper) SwitchToMerge(path string) error {
 		}
 	}
 
-	return self.c.PushContext(self.c.Contexts().MergeConflicts)
+	self.c.Context().Push(self.c.Contexts().MergeConflicts)
+	return nil
 }
 
 func (self *MergeConflictsHelper) context() *context.MergeConflictsContext {
 	return self.c.Contexts().MergeConflicts
 }
 
-func (self *MergeConflictsHelper) Render() error {
+func (self *MergeConflictsHelper) Render() {
 	content := self.context().GetContentToRender()
 
 	var task types.UpdateTask
@@ -111,7 +112,7 @@ func (self *MergeConflictsHelper) Render() error {
 		task = types.NewRenderStringWithScrollTask(content, 0, originY)
 	}
 
-	return self.c.RenderToMainViews(types.RefreshMainOpts{
+	self.c.RenderToMainViews(types.RefreshMainOpts{
 		Pair: self.c.MainViewPairs().MergeConflicts,
 		Main: &types.ViewUpdateOpts{
 			Task: task,
@@ -123,7 +124,7 @@ func (self *MergeConflictsHelper) RefreshMergeState() error {
 	self.c.Contexts().MergeConflicts.GetMutex().Lock()
 	defer self.c.Contexts().MergeConflicts.GetMutex().Unlock()
 
-	if self.c.CurrentContext().GetKey() != context.MERGE_CONFLICTS_CONTEXT_KEY {
+	if self.c.Context().Current().GetKey() != context.MERGE_CONFLICTS_CONTEXT_KEY {
 		return nil
 	}
 
