@@ -202,6 +202,86 @@ func TestGetWindowDimensions(t *testing.T) {
 			B: information
 			`,
 		},
+		{
+			name: "0.5 SidePanelWidth",
+			mutateArgs: func(args *WindowArrangementArgs) {
+				args.UserConfig.Gui.SidePanelWidth = 0.5
+			},
+			expected: `
+			╭status──────────────────────────────╮╭main───────────────────────────────╮
+			│                                    ││                                   │
+			╰────────────────────────────────────╯│                                   │
+			╭files───────────────────────────────╮│                                   │
+			│                                    ││                                   │
+			│                                    ││                                   │
+			│                                    ││                                   │
+			│                                    ││                                   │
+			│                                    ││                                   │
+			│                                    ││                                   │
+			╰────────────────────────────────────╯│                                   │
+			╭branches────────────────────────────╮│                                   │
+			│                                    ││                                   │
+			│                                    ││                                   │
+			│                                    ││                                   │
+			│                                    ││                                   │
+			│                                    ││                                   │
+			│                                    ││                                   │
+			╰────────────────────────────────────╯│                                   │
+			╭commits─────────────────────────────╮│                                   │
+			│                                    ││                                   │
+			│                                    ││                                   │
+			│                                    ││                                   │
+			│                                    ││                                   │
+			│                                    ││                                   │
+			╰────────────────────────────────────╯│                                   │
+			╭stash───────────────────────────────╮│                                   │
+			│                                    ││                                   │
+			╰────────────────────────────────────╯╰───────────────────────────────────╯
+			<options──────────────────────────────────────────────────────>A<B────────>
+			A: statusSpacer1
+			B: information
+			`,
+		},
+		{
+			name: "0.8 SidePanelWidth",
+			mutateArgs: func(args *WindowArrangementArgs) {
+				args.UserConfig.Gui.SidePanelWidth = 0.8
+			},
+			expected: `
+			╭status────────────────────────────────────────────────────╮╭main─────────╮
+			│                                                          ││             │
+			╰──────────────────────────────────────────────────────────╯│             │
+			╭files─────────────────────────────────────────────────────╮│             │
+			│                                                          ││             │
+			│                                                          ││             │
+			│                                                          ││             │
+			│                                                          ││             │
+			│                                                          ││             │
+			│                                                          ││             │
+			╰──────────────────────────────────────────────────────────╯│             │
+			╭branches──────────────────────────────────────────────────╮│             │
+			│                                                          ││             │
+			│                                                          ││             │
+			│                                                          ││             │
+			│                                                          ││             │
+			│                                                          ││             │
+			│                                                          ││             │
+			╰──────────────────────────────────────────────────────────╯│             │
+			╭commits───────────────────────────────────────────────────╮│             │
+			│                                                          ││             │
+			│                                                          ││             │
+			│                                                          ││             │
+			│                                                          ││             │
+			│                                                          ││             │
+			╰──────────────────────────────────────────────────────────╯│             │
+			╭stash─────────────────────────────────────────────────────╮│             │
+			│                                                          ││             │
+			╰──────────────────────────────────────────────────────────╯╰─────────────╯
+			<options──────────────────────────────────────────────────────>A<B────────>
+			A: statusSpacer1
+			B: information
+			`,
+		},
 		{
 			name: "half screen mode, enlargedSideViewLocation left",
 			mutateArgs: func(args *WindowArrangementArgs) {
