@@ -51,15 +51,21 @@ func (self *ListController) HandleScrollRight() error {
 }
 
 func (self *ListController) HandleScrollUp() error {
-	scrollHeight := self.c.UserConfig.Gui.ScrollHeight
+	scrollHeight := self.c.UserConfig().Gui.ScrollHeight
 	self.context.GetViewTrait().ScrollUp(scrollHeight)
+	if self.context.RenderOnlyVisibleLines() {
+		self.context.HandleRender()
+	}
 
 	return nil
 }
 
 func (self *ListController) HandleScrollDown() error {
-	scrollHeight := self.c.UserConfig.Gui.ScrollHeight
+	scrollHeight := self.c.UserConfig().Gui.ScrollHeight
 	self.context.GetViewTrait().ScrollDown(scrollHeight)
+	if self.context.RenderOnlyVisibleLines() {
+		self.context.HandleRender()
+	}
 
 	return nil
 }
@@ -67,7 +73,8 @@ func (self *ListController) HandleScrollDown() error {
 func (self *ListController) scrollHorizontal(scrollFunc func()) error {
 	scrollFunc()
 
-	return self.context.HandleFocus(types.OnFocusOpts{})
+	self.context.HandleFocus(types.OnFocusOpts{})
+	return nil
 }
 
 func (self *ListController) handleLineChange(change int) error {
@@ -100,16 +107,16 @@ func (self *ListController) handleLineChangeAux(f func(int), change int) error {
 	cursorMoved := before != after
 	if cursorMoved {
 		if change == -1 {
-			checkScrollUp(self.context.GetViewTrait(), self.c.UserConfig,
+			checkScrollUp(self.context.GetViewTrait(), self.c.UserConfig(),
 				self.context.ModelIndexToViewIndex(before), self.context.ModelIndexToViewIndex(after))
 		} else if change == 1 {
-			checkScrollDown(self.context.GetViewTrait(), self.c.UserConfig,
+			checkScrollDown(self.context.GetViewTrait(), self.c.UserConfig(),
 				self.context.ModelIndexToViewIndex(before), self.context.ModelIndexToViewIndex(after))
 		}
 	}
 
 	if cursorMoved || rangeBefore != rangeAfter {
-		return self.context.HandleFocus(types.OnFocusOpts{})
+		self.context.HandleFocus(types.OnFocusOpts{})
 	}
 
 	return nil
@@ -136,7 +143,8 @@ func (self *ListController) HandleToggleRangeSelect() error {
 
 	list.ToggleStickyRange()
 
-	return self.context.HandleFocus(types.OnFocusOpts{})
+	self.context.HandleFocus(types.OnFocusOpts{})
+	return nil
 }
 
 func (self *ListController) HandleRangeSelectDown() error {
@@ -165,21 +173,20 @@ func (self *ListController) HandleClick(opts gocui.ViewMouseBindingOpts) error {
 	if prevSelectedLineIdx == newSelectedLineIdx && alreadyFocused && self.context.GetOnClick() != nil {
 		return self.context.GetOnClick()()
 	}
-	return self.context.HandleFocus(types.OnFocusOpts{})
+	self.context.HandleFocus(types.OnFocusOpts{})
+	return nil
 }
 
 func (self *ListController) pushContextIfNotFocused() error {
 	if !self.isFocused() {
-		if err := self.c.PushContext(self.context); err != nil {
-			return err
-		}
+		self.c.Context().Push(self.context)
 	}
 
 	return nil
 }
 
 func (self *ListController) isFocused() bool {
-	return self.c.CurrentContext().GetKey() == self.context.GetKey()
+	return self.c.Context().Current().GetKey() == self.context.GetKey()
 }
 
 func (self *ListController) GetKeybindings(opts types.KeybindingsOpts) []*types.Binding {
