@@ -174,6 +174,10 @@ func (self *Shell) EmptyCommit(message string) *Shell {
 	return self.RunCommand([]string{"git", "commit", "--allow-empty", "-m", message})
 }
 
+func (self *Shell) EmptyCommitWithBody(subject string, body string) *Shell {
+	return self.RunCommand([]string{"git", "commit", "--allow-empty", "-m", subject, "-m", body})
+}
+
 func (self *Shell) EmptyCommitDaysAgo(message string, daysAgo int) *Shell {
 	return self.RunCommand([]string{"git", "commit", "--allow-empty", "--date", fmt.Sprintf("%d days ago", daysAgo), "-m", message})
 }
@@ -190,6 +194,10 @@ func (self *Shell) Revert(ref string) *Shell {
 	return self.RunCommand([]string{"git", "revert", ref})
 }
 
+func (self *Shell) AssertRemoteTagNotFound(upstream, name string) *Shell {
+	return self.RunCommandExpectError([]string{"git", "ls-remote", "--exit-code", upstream, fmt.Sprintf("refs/tags/%s", name)})
+}
+
 func (self *Shell) CreateLightweightTag(name string, ref string) *Shell {
 	return self.RunCommand([]string{"git", "tag", name, ref})
 }
