@@ -43,8 +43,8 @@ var AmendHeadCommitDuringRebase = NewIntegrationTest(NewIntegrationTestArgs{
 			Press(keys.Commits.AmendToCommit).
 			Tap(func() {
 				t.ExpectPopup().Confirmation().
-					Title(Equals("Amend last commit")).
-					Content(Contains("Are you sure you want to amend last commit?")).
+					Title(Equals("Amend commit")).
+					Content(Contains("Are you sure you want to amend this commit with your staged files?")).
 					Confirm()
 			}).
 			Lines(
